@@ -6,8 +6,9 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..11\n"; }
+BEGIN { $| = 1; print "1..12\n"; }
 END {print "not ok 1\n" unless $loaded;}
+
 use Getopt::Declare;
 $::loaded = 1;
 print "ok 1\n";
@@ -22,16 +23,22 @@ sub ok
 	$count++;
 }
 
-sub debug { print @_ if 0 }
+sub debug
+{
+	print @_ if 0;
+}
 
 ######################### End of black magic.
 
-@ARGV = ("bee",'BB BB',
-	 "-aA", "s e e",
-	 "remainder",
-	 '+d', '1', '2', '3', '-1',
-	 '-yz',
-	 '+d', '1', '2', '3', '-1', 'a',
+@ARGV = (
+	  'bee',       'BB BB',
+	  '--out',     'dummy.txt',
+	  '-aA',
+          's e e',
+	  'remainder',
+	  '+d',        '9', '1.2345', '1e3', '2.1E-01', '.3', '-1',
+	  '-yz',
+	  '+d',        '9', '1.2345', '1e3', '2.1E-01', '.3', '-1', 'a',
 	);
 
 my $args = new Getopt::Declare (q
@@ -56,30 +63,34 @@ my $args = new Getopt::Declare (q
 				{ $_VAL_ = '<undef>' unless defined $_VAL_;
 				  ::debug "matched $_PARAM_\t($_VAL_)\n" }
 
-	<d>		option 6
+	--out <out:of>...	option 6
+				{ $_VAL_ = '<undef>' unless defined $_VAL_;
+				  ::debug "matched $_PARAM_\t($_VAL_)\n" }
+
+	<d>		option 7
 				{ $_VAL_ = '<undef>' unless defined $_VAL_;
 				  ::debug "rejected $_PARAM_\t($_VAL_)\n" }
 				{ reject }
 				{ $_VAL_ = '<undef>' unless defined $_VAL_;
 				  ::debug "matched $_PARAM_\t($_VAL_)\n" }
 
-	-y		option 7
+	-y		option 8
 				{ $_VAL_ = '<undef>' unless defined $_VAL_;
 				  ::debug "matched $_PARAM_\t($_VAL_)\n" }
 
-	-z		option 8
+	-z		option 9
 				{ $_VAL_ = '<undef>' unless defined $_VAL_;
 				  ::debug "matched $_PARAM_\t($_VAL_)\n" }
-
 });
 
 ok $args;
-ok $args->{-a} eq "A";
-ok $args->{bee} eq "BB BB";
-ok $args->{"<c>"} eq "s e e";
-ok join(',',@{$args->{'+d'}}) eq '1,2,3,1,2,3';
+ok $args->{'-a'} eq 'A';
+ok $args->{'bee'} eq 'BB BB';
+ok $args->{'<c>'} eq 's e e';
+ok join(',',@{$args->{'+d'}}) eq '9,1.2345,1e3,2.1E-01,.3,9,1.2345,1e3,2.1E-01,.3';
 ok !($args->{'<d>'});
 ok $args->{'-1'};
+ok ${$args->{'--out'}}[0] eq 'dummy.txt';
 ok @ARGV==2;
 ok $ARGV[0] eq 'remainder';
 ok $ARGV[1] eq 'a';
